searchNodes=[{"doc":"Defines a set of guards that can be used with Elixir functions.Each guard operates on a UTF8 codepoint since the permitted operators in a guard clause are restricted to simple comparisons that do not include string comparators.The data that underpins these guards is generated from the Unicode character database and therefore includes a broad range of scripts well beyond the basic ASCII definitions.","ref":"Unicode.Guards.html","title":"Unicode.Guards","type":"module"},{"doc":"Guards whether a UTF8 codepoint is a space character.This is the Unicode definition of those characters that horizontal space (space, non-breaking space etc) as well as the horizontal tab character.","ref":"Unicode.Guards.html#is_blank/1","title":"Unicode.Guards.is_blank/1","type":"macro"},{"doc":"Guards whether a UTF8 codepoint is a currency symbol character.","ref":"Unicode.Guards.html#is_currency_symbol/1","title":"Unicode.Guards.is_currency_symbol/1","type":"macro"},{"doc":"Guards whether a UTF8 codepoint is a digit character.This guard will match any digit character from any Unicode script, not only the ASCII decimal digits.","ref":"Unicode.Guards.html#is_digit/1","title":"Unicode.Guards.is_digit/1","type":"macro"},{"doc":"Guards whether a UTF8 codepoint is a graphic character.This is the Unicode definition of those characters that are visible. It is defined as those characters that are non-space, non-control and non-surrogate.","ref":"Unicode.Guards.html#is_graph/1","title":"Unicode.Guards.is_graph/1","type":"macro"},{"doc":"Guards whether a UTF8 codepoint is a lower case character.The match is for any UTF8 character that is defined in Unicode to be an lower case character in any script.","ref":"Unicode.Guards.html#is_lower/1","title":"Unicode.Guards.is_lower/1","type":"macro"},{"doc":"Guargs where a UTF8 codepoint is a printing character.This is the Unicode definition which is a combination of the [:graph:] set and the [:blank:] set.","ref":"Unicode.Guards.html#is_print/1","title":"Unicode.Guards.is_print/1","type":"macro"},{"doc":"Guards whether a UTF8 codepoint is a printable.The definition of what is printable is the same as used by String.printable?/1","ref":"Unicode.Guards.html#is_printable/1","title":"Unicode.Guards.is_printable/1","type":"macro"},{"doc":"Guards whether a UTF8 codepoint is a unicode quote symbol character.This includes the Unicode set Pi, Pf and other characters documents in this Wikpedia article.See also Unicode.Category.QuoteMarks.","ref":"Unicode.Guards.html#is_quote_mark/1","title":"Unicode.Guards.is_quote_mark/1","type":"macro"},{"doc":"Guards whether a UTF8 codepoint is a unicode quote symbol that can be used either left or right.See also Unicode.Category.QuoteMarks.","ref":"Unicode.Guards.html#is_quote_mark_ambidextrous/1","title":"Unicode.Guards.is_quote_mark_ambidextrous/1","type":"macro"},{"doc":"Guards whether a UTF8 codepoint is a unicode quote symbol that is considered a single quote.See also Unicode.Category.QuoteMarks.","ref":"Unicode.Guards.html#is_quote_mark_double/1","title":"Unicode.Guards.is_quote_mark_double/1","type":"macro"},{"doc":"Guards whether a UTF8 codepoint is a unicode left quote symbol character.See also Unicode.Category.QuoteMarks.","ref":"Unicode.Guards.html#is_quote_mark_left/1","title":"Unicode.Guards.is_quote_mark_left/1","type":"macro"},{"doc":"Guards whether a UTF8 codepoint is a unicode right quote symbol character.See also Unicode.Category.QuoteMarks.","ref":"Unicode.Guards.html#is_quote_mark_right/1","title":"Unicode.Guards.is_quote_mark_right/1","type":"macro"},{"doc":"Guards whether a UTF8 codepoint is a unicode quote symbol that is considered a single quote.See also Unicode.Category.QuoteMarks.","ref":"Unicode.Guards.html#is_quote_mark_single/1","title":"Unicode.Guards.is_quote_mark_single/1","type":"macro"},{"doc":"Guards whether a UTF8 codepoint is a unicode separator symbol character.This includes the Unicode set Zs plus the characters.","ref":"Unicode.Guards.html#is_separator/1","title":"Unicode.Guards.is_separator/1","type":"macro"},{"doc":"Guards whether a UTF8 codepoint is an upper case character.The match is for any UTF8 character that is defined in Unicode to be an upper case character in any script.","ref":"Unicode.Guards.html#is_upper/1","title":"Unicode.Guards.is_upper/1","type":"macro"},{"doc":"Guards whether a UTF8 codepoint is a whitespace symbol character.This includes the Unicode set Zs plus the characters in the range 0x9-0xd which incudes tab, newline and carriage return.","ref":"Unicode.Guards.html#is_whitespace/1","title":"Unicode.Guards.is_whitespace/1","type":"macro"},{"doc":"Unicode GuardsProvides a set of function guards that can be used to match Unicode codepoints. Based upon ex_unicode and unicode_set.","ref":"readme.html","title":"Unicode Guards","type":"extras"},{"doc":"Each guard operates on a UTF8 codepoint since the permitted operators in a guard clause are restricted to simple comparisons that do not include strings.The data that underpins these guards is generated from the Unicode character database and therefore includes a broad range of scripts well beyond the basic ASCII definitions.Some examples follow defining functions using the pre-defined guards. Note that since guards operate on codepoints (not strings) we use binary pattern matching to extract the first codepoint for these example.defmodule Guards do import Unicode.Guards def upper(&lt;&lt; x :: utf8, _rest :: binary &gt;&gt;) when is_upper(x), do: :upper def lower(&lt;&lt; x :: utf8, _rest :: binary &gt;&gt;) when is_lower(x), do: :lower def digit(&lt;&lt; x :: utf8, _rest :: binary &gt;&gt;) when is_digit(x), do: :digit def whitespace(&lt;&lt; x :: utf8, _rest :: binary &gt;&gt;) when is_whitespace(x), do: :whitespace def currency(&lt;&lt; x :: utf8, _rest :: binary &gt;&gt;) when is_currency_symbol(x), do: :currency end","ref":"readme.html#usage","title":"Unicode Guards - Usage","type":"extras"},{"doc":"The package can be installed by adding unicode_guards to your list of dependencies in mix.exs:def deps do [ {:unicode_guards, &quot;~&gt; 0.2.0&quot;} ] endThe docs can be found at https://hexdocs.pm/unicode_guards.","ref":"readme.html#installation","title":"Unicode Guards - Installation","type":"extras"},{"doc":"LicenseCopyright 2019 Kip ColeLicensed under the Apache License, Version 2.0 (the &quot;License&quot;); you may not use this file except in compliance with the License. You may obtain a copy of the License athttp://www.apache.org/licenses/LICENSE-2.0Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an &quot;AS IS&quot; BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.","ref":"license.html","title":"License","type":"extras"},{"doc":"Changelog for Unicode Guards v0.5.0This is the changelog for Unicode Guards v0.5.0 released on December 5th, 2020. For older changelogs please consult the release tag on GitHub","ref":"changelog.html","title":"Changelog for Unicode Guards v0.5.0","type":"extras"},{"doc":"Relax version requirement for nimble_parsec to allow &quot;~&gt; 0.5 or ~&gt; 1.0&quot;. Thanks to @@fireproofsocks. Closes #3.Changelog for Unicode Guards v0.4.0This is the changelog for Unicode Guards v0.4.0 released on October 13th, 2020. For older changelogs please consult the release tag on GitHub","ref":"changelog.html#bug-fixes","title":"Changelog for Unicode Guards v0.5.0 - Bug Fixes","type":"extras"},{"doc":"Fix ex_doc dependency. Thanks to @nickdichev.","ref":"changelog.html#bug-fixes","title":"Changelog for Unicode Guards v0.5.0 - Bug Fixes","type":"extras"},{"doc":"Add additional guards is_graph?/1, is_blank?/1 and is_print/1 that match the definitions for Unicode regexes.Changelog for Unicode Guards v0.3.1This is the changelog for Unicode Guards v0.3.1 released on May 21st, 2020. For older changelogs please consult the release tag on GitHub","ref":"changelog.html#enhancements","title":"Changelog for Unicode Guards v0.5.0 - Enhancements","type":"extras"},{"doc":"Fix escape sequences in is_whitespace/2 guard. Thanks to @nickdichev, closes #1Changelog for Unicode Guards v0.3.0This is the changelog for Unicode Guards v0.3.0 released on March 14th, 2020. For older changelogs please consult the release tag on GitHub","ref":"changelog.html#bug-fixes","title":"Changelog for Unicode Guards v0.5.0 - Bug Fixes","type":"extras"},{"doc":"Add is_printable/1 that uses the same semantics as String.printable?/1Add is_visible/1 that uses the Unicode set [[:L:][:N:][:M:][:P:][:S:][:Zs:]]Changelog for Unicode Guards v0.2.0This is the changelog for Unicode Guards v0.2.0 released on March 11th, 2020. For older changelogs please consult the release tag on GitHub","ref":"changelog.html#enhancements","title":"Changelog for Unicode Guards v0.5.0 - Enhancements","type":"extras"},{"doc":"Add guards for quote marks. Adds:is_quote_mark/1is_quote_mark_left/1is_quote_mark_right/1is_quote_mark_ambidextrous/1is_quote_mark_single/1is_quote_mark_double/1Changelog for Unicode Guards v0.1.1This is the changelog for Unicode Guards v0.1.1 released on February 25th, 2020. For older changelogs please consult the release tag on GitHubBug FixesCorrects is_whitespace/1 to include the expected characters in the range 0x9-0xd. These comprise carriage return, newline, vertical tab and tab which are commonly considered by regex engines to be whitespace.Changelog for Unicode Guards v0.1.0This is the changelog for Unicode Guards v0.1.0 released on November 23rd, 2019. For older changelogs please consult the release tag on GitHubInitial release.","ref":"changelog.html#enhancements","title":"Changelog for Unicode Guards v0.5.0 - Enhancements","type":"extras"}]